@@ -39,13 +39,13 @@ class DownloadProgressBar(FileSystemEventHandler):
     def on_any_event(self, event):
         self.update()
 
-    def update(self):
+    def update(self, end=False):
         fl = [f for f in os.listdir(self.watch_dir) if not f.endswith('.part')]
         cur_num = len(fl)
         update_num = cur_num - self.last_num
         self.last_num = cur_num
         self.pbar.update(update_num) 
-        if self.last_num != self.total_num:
+        if end and self.last_num != self.total_num:
             print()
 
 
@@ -179,7 +179,7 @@ class BasicManga:
                     tmp_images.append(image)
             images = tmp_images
 
-        event_handler.update()
+        event_handler.update(end=True)
         observer.stop()
         observer.join()
             
